Learn R Programming

tidygapminder (version 0.1.1)

tidy_bunch: Tidy Gapminder indicator data sheets stored in a folder using tidy_indice.

Description

Tidy Gapminder indicator data sheets stored in a folder using tidy_indice.

Usage

tidy_bunch(dirpath = ".", merge = FALSE, ...)

Arguments

dirpath

Path to folder containing indices data sheets.

merge

A boolean. If true, combines all indices data sheets in one. Default: FALSE.

...

Ellipsis.

Value

List of indices data frames tidied (if merge = FALSE) or a single data frame of all indices tidied (if merge = TRUE).

Examples

Run this code
# NOT RUN {
folder_path <- system.file("extdata", package = "tidygapminder")

tidy_bunch(folder_path)

# }

Run the code above in your browser using DataLab