powered by
tidy_indice
Tidy Gapminder indicator data sheets stored in a folder using tidy_indice.
tidy_bunch(dirpath = ".", merge = FALSE, ...)
Path to folder containing indices data sheets.
A boolean. If true, combines all indices data sheets in one. Default: FALSE.
Ellipsis.
List of indices data frames tidied (if merge = FALSE) or a single data frame of all indices tidied (if merge = TRUE).
merge
# NOT RUN { folder_path <- system.file("extdata", package = "tidygapminder") tidy_bunch(folder_path) # }
Run the code above in your browser using DataLab